---
layout: page
title: Docs
permalink: /docs/

---

F-Droid is both a repository of verified free software Android apps as
well as a whole "app store kit", providing all the tools needed to
setup and run an app store. It is a community-run free software
project developed by a wide range of contributors. It also includes
complete build and release tools for managing the process of turning
app source code into published builds.

The F-Droid server tools provide various scripts and tools that are used
to maintain the main F-Droid application repository. You can use these
same tools to create your own additional or alternative repository for
publishing, or to assist in creating, testing and submitting metadata to
the main repository.


### Getting Started

* [FAQ - General](FAQ_-_General) Frequently Asked Questions about F-Droid
* [FAQ - Client](FAQ_-_Client) Frequently Asked Questions about how to use the F-Droid app in Android.
* [Anti-Features](Anti-Features) What they are, what they mean, and what apps have them.
* [Tutorials](../tutorials) Step-by-step tutorials on features in F-Droid


### More Information

* [Code of Conduct](Code_of_Conduct) How to behave when communicating within F-Droid.
* [How to Help](How_to_Help) Different ways anyone can contribute to the F-Droid project.
* [Running on old Android versions](Running_on_old_Android_versions) A list of F-Droid releases for no longer supported Android versions.
* [Known Repositories](https://forum.f-droid.org/t/721) A list that tries to keep track of known F-Droid compatible repositories.
* [Release Channels and Signing Keys](Release_Channels_and_Signing_Keys) These are the various channels that F-Droid software are released on, with info to verify them based on signing keys.
* [Security Model](Security_Model) A brief explanation of how F-Droid delivers software to users securely.
* [Repomaker](../repomaker) A user-friendly tool for managing custom repos
* [Translation and Localization](Translation_and_Localization) How all the parts of F-Droid are localized.
* [Tips & Tricks](https://forum.f-droid.org/c/wiki/tips-and-tricks) A collection of useful tips and tricks that make life around F-Droid easier.
* [All our APIs](All_our_APIs) Public API endpoints for data about _f-droid.org_, repos, mirrors, Android, Gradle, and more
* [Wiki](https://gitlab.com/fdroid/wiki/-/wikis/home) For everything else that people want to document.
* [Take-Down Requests](Take-Down_Requests) Our policy about requesting the removal of apps or content from _f-droid.org_.


### Developers

* [FAQ - App Developers](FAQ_-_App_Developers) Frequently Asked Questions about F-Droid
* [Build Metadata Reference](Build_Metadata_Reference) All about the build "recipes"
* [Submitting to F-Droid: Quick Start Guide](Submitting_to_F-Droid_Quick_Start_Guide) Add an app to f-droid.org
* [Update Processing](Update_Processing) How updates get detected and added.
* [Inclusion Policy](Inclusion_Policy) & [Inclusion How-To](Inclusion_How-To)  Guidelines for how to request the inclusion of a new app.
* [Importing Applications](Importing_Applications) Using `fdroid import` to build a new project.
* [Building Applications](Building_Applications) Using `fdroid build` to build an app.
* [All About Descriptions, Graphics, and Screenshots](All_About_Descriptions_Graphics_and_Screenshots) Showing off your app in F-Droid.
* [Publishing Nightly Builds](Publishing_Nightly_Builds) Make an automated repo of nightly builds of your app.
* [Installing the Server and Repo Tools](Installing_the_Server_and_Repo_Tools) How to install fdroidserver, the tools for running repos and build servers.
* [Setup an F-Droid App Repo](Setup_an_F-Droid_App_Repo) How to setup your own repository of apps that users can easily add to their F-Droid client to get your apps directly from the source.
* [Build Server Setup](Build_Server_Setup) How to setup the complete f-droid.org build setup on your own machine.
* [Signing Process](Signing_Process) How to setup cryptographic signatures with F-Droid tools
* [Reproducible Builds](Reproducible_Builds) How to use the F-Droid tools to make reproducible builds easy.
* [Building a Signing Server](Building_a_Signing_Server) For higher security, isolate the signing keys from the rest.
* [Verification Server](Verification_Server) Setting up a server to verify app builds are correct.
* [Whitelabel Builds](Whitelabel_Builds) custom builds of F-Droid
* [Privileged Extension](https://gitlab.com/fdroid/privileged-extension/#f-droid-privileged-extension) How to use F-Droid Privileged Extension as a user and rom developer
* [Deploying the Website](Deploying_the_Website) How [fdroid-website.git](https://gitlab.com/fdroid/fdroid-website) becomes [f-droid.org](https://f-droid.org)
* [Maintaining the Forum](Maintaining_the_Forum) Useful information for administrators of [F-Droid's forum](https://forum.f-droid.org)
* [Running a Mirror](Running_a_Mirror) Instructions for setting up a repository mirror
* [MIA Process](MIA_Process) MIA (missing in action) maintainer removal process
