---
layout: post
title: "Why curation and decentralization is better than millions of apps"
author: eighthave
---

Every desktop computer or mobile device comes with some form of "app store".  There is F-Droid for Android.  Debian has "software repositories" at its core.  Then there are the really big, proprietary ones: Apple App Store and Google Play.  These have millions of apps, while Debian has tens of thousands, and F-Droid around 4,000.  This statistic is commonly mentioned when the big app stores promote themselves.  When comparing by this number, F-Droid is a tiny little blip.  But really, how many apps do you need in your app store?

Every software collection is fundamentally an act of curation.  Only useful software is included.  Malicious software is filtered out.  Software deemed illegal in your jurisdiction is blocked.  Any software that does not meet the standards or terms of service is removed.  In the cases of community-curated distros like Debian or F-Droid, the contributors curate by choosing which apps are worth their attention.  There is no major end-user software distribution that does not curate.  Ideally, it is software that is useful to you, the user. Sadly, that is often not true.  Think of the [companies that prioritize surveillance capitalism](https://gizmodo.com/study-vast-majority-of-google-play-apps-are-covertly-t-1820821682): they include software designed to capture your attention so they can sell to advertisers.  Or some companies promise privacy protections from apps, but then [exempt their own software](https://gizmodo.com/apple-app-store-iphone-ads-privacy-antitrust-germany-pr-1849058746) from the privacy protections.

From the point of the user, the ideal app store would contain exactly what the user wants, and not one thing more.  Nobody has millions of apps installed on their device.  All those extra apps just get in the way of finding what is important.  Even worse, in the big app stores, its not just noise, it is [malware](https://arstechnica.com/information-technology/2020/04/sophisticated-android-backdoors-have-been-populating-google-play-for-years/) or companies trying to rope you into something.  They are trying to be the flashiest thing so people click the "buy" button.  Or worse, they are trying to [addict](https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0180094) you so that they can sell your data to advertisers.

F-Droid is organized around different principles: user choice, decentralization, and community-controlled curation.  This means F-Droid gives you selected apps by default without bans or censorship.  When you install the F-Droid app, it automatically connects to the collection on f-droid.org that is maintained by this community.  F-Droid also makes it easy for anyone to publish their own repository, with their own curation rules.  [Repomaker](https://gitlab.com/fdroid/repomaker) is a easy web app for publishing, and the _fdroidserver_ command line tools that power f-droid.org are available for power users.

Organizing this way makes a lot of hard questions go away.  Children, hackers, religious people, grandparents, activists, bachelors, and adult film actors; we all use calendars, read the news, need help navigating, play games.  Over the years, a rough consensus has formed within the f-droid.org community that our collection should be curated this way.  This turns out to be quite similar to other free software communities, like Debian.  This blog post aims to make this more explicit to our users.

Every society has accepted ways to communicate about offensive things.  If f-droid.org is the one source of software, then our curation would be censorship, since we would be preventing speech.  As supporters of free software and privacy, we also want nothing to do with censorship.  That's where decentralization comes in.  Decentralization means people can choose who they trust in a fine-grained way, not all or nothing.  We have put a lot of work into making it easy for anyone to make their own app repos, and those repos can follow any rules that its creators want.  Since F-Droid repos are a form of user-controlled subscription, it is not the place for F-Droid contributors to decide.  Which apps or repos an F-Droid user includes in their own devices is entirely up to them.

One common complaint about decentralized systems is that they work badly.  That is not true for the Android app ecosystem, and software distribution in general. Software repositories are usually not monolithic, the big mobile app stores are really the exception.  Windows allows many sources.  [GNOME Software](https://apps.gnome.org/app/org.gnome.Software/) has one seamless experience based on _apt_, _dnf_, Flatpak, Snapcraft, etc. as software sources.  In the [Chinese app store market](https://www.forbes.com/sites/eladnatanson/2019/09/03/the-other-android-app-stores-a-new-frontier-for-app-discovery/) five to ten commonly used app stores, and yet even the largest has less than a majority market share.  Most Chinese people have more than one app store on their phone, so there is no monolith there, whereas ["outside of China, Apple and Google control more than 95 percent of the app store market share"](https://www.businessofapps.com/data/app-stores/).  Ecosystems with multiple app sources work, and governments around the world believe that [monopoly](https://www.vox.com/recode/2021/7/7/22567656/google-play-store-states-antitrust-suit-letitia-james-utah-new-york-north-carolina) [forces](https://www.medianama.com/2022/07/223-summary-digital-markets-inquiry-south-africa/) [are](https://www.accc.gov.au/focus-areas/inquiries-ongoing/digital-platform-services-inquiry-2020-2025/march-2022-interim-report) [what](https://www.compcom.co.za/online-intermediation-platforms-market-inquiry-provisional-report/) [keeps](https://www.reuters.com/article/us-eu-google-antitrust-idUSKCN1MQ2DI) [Google](https://www.gov.uk/cma-cases/investigation-into-suspected-anti-competitive-conduct-by-google) [Play](https://economictimes.indiatimes.com/tech/technology/cci-probe-finds-googles-play-store-billing-guidelines-unfair-and-discriminatory/articleshow/90550596.cms) [and](https://www.theverge.com/2021/9/14/22673202/google-south-korea-android-fork-fine-anti-fragmentation-agreement-antitrust) [Apple](https://www.engadget.com/uk-regulator-probe-google-apple-mobile-duopoly-130013629.html) [App](https://techcrunch.com/2021/06/15/uks-cma-opens-market-study-into-apple-googles-mobile-duopoly/) [Store](https://www.gov.uk/government/news/cma-and-global-partners-secure-privacy-changes-to-the-app-store) dominant.  Even Apple's famous strictly walled garden can coexist with [AltStore](https://altstore.io/), [AppFair](https://appfair.app/), and [Cydia](https://cydia.saurik.com/).  This clearly demonstrates that the only barrier to breaking down the app monoliths are the policies of monopolist companies.

The point remains: for the vast majority of Apple iOS and Google Play device users, when the store removes or restricts an app it is essentially censorship.  Using alternatives requires a high level of technical skill.  Google Play devices at least allow third party app stores, albeit with a much lower level of integration than Google Play itself.  Not only does F-Droid offer truly open app distribution, the F-Droid model offers an improved user experience: many decentralized app repositories can be managed in a single F-Droid client app.  So there is the ease of use provided by a unified user experience, but it is not locked to a single provider.  Only when there is a free, open, decentralized ecosystem can everyone decide for themselves what apps they want while also choosing which apps they do not want to see.  The freedom to get apps will always be in tension with the things that people want to keep out of their life.  Decentralization is the only solution, and F-Droid is built from the ground up to enable it.
